# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from slack_beta_ti.models.default_success_template import DefaultSuccessTemplate

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class AdminUsersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def admin_users_assign(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to add to the workspace.")],
        is_restricted: Annotated[Optional[StrictBool], Field(description="True if user should be added to the workspace as a guest.")] = None,
        is_ultra_restricted: Annotated[Optional[StrictBool], Field(description="True if user should be added to the workspace as a single-channel guest.")] = None,
        channel_ids: Annotated[Optional[StrictStr], Field(description="Comma separated values of channel IDs to add user in the new workspace.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_assign

        Add an Enterprise user to a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to add to the workspace. (required)
        :type user_id: str
        :param is_restricted: True if user should be added to the workspace as a guest.
        :type is_restricted: bool
        :param is_ultra_restricted: True if user should be added to the workspace as a single-channel guest.
        :type is_ultra_restricted: bool
        :param channel_ids: Comma separated values of channel IDs to add user in the new workspace.
        :type channel_ids: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_assign_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            is_restricted=is_restricted,
            is_ultra_restricted=is_ultra_restricted,
            channel_ids=channel_ids,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_assign_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to add to the workspace.")],
        is_restricted: Annotated[Optional[StrictBool], Field(description="True if user should be added to the workspace as a guest.")] = None,
        is_ultra_restricted: Annotated[Optional[StrictBool], Field(description="True if user should be added to the workspace as a single-channel guest.")] = None,
        channel_ids: Annotated[Optional[StrictStr], Field(description="Comma separated values of channel IDs to add user in the new workspace.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_assign

        Add an Enterprise user to a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to add to the workspace. (required)
        :type user_id: str
        :param is_restricted: True if user should be added to the workspace as a guest.
        :type is_restricted: bool
        :param is_ultra_restricted: True if user should be added to the workspace as a single-channel guest.
        :type is_ultra_restricted: bool
        :param channel_ids: Comma separated values of channel IDs to add user in the new workspace.
        :type channel_ids: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_assign_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            is_restricted=is_restricted,
            is_ultra_restricted=is_ultra_restricted,
            channel_ids=channel_ids,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_assign_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to add to the workspace.")],
        is_restricted: Annotated[Optional[StrictBool], Field(description="True if user should be added to the workspace as a guest.")] = None,
        is_ultra_restricted: Annotated[Optional[StrictBool], Field(description="True if user should be added to the workspace as a single-channel guest.")] = None,
        channel_ids: Annotated[Optional[StrictStr], Field(description="Comma separated values of channel IDs to add user in the new workspace.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_assign

        Add an Enterprise user to a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to add to the workspace. (required)
        :type user_id: str
        :param is_restricted: True if user should be added to the workspace as a guest.
        :type is_restricted: bool
        :param is_ultra_restricted: True if user should be added to the workspace as a single-channel guest.
        :type is_ultra_restricted: bool
        :param channel_ids: Comma separated values of channel IDs to add user in the new workspace.
        :type channel_ids: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_assign_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            is_restricted=is_restricted,
            is_ultra_restricted=is_ultra_restricted,
            channel_ids=channel_ids,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_assign_serialize(
        self,
        token,
        team_id,
        user_id,
        is_restricted,
        is_ultra_restricted,
        channel_ids,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if user_id is not None:
            _form_params.append(('user_id', user_id))
        if is_restricted is not None:
            _form_params.append(('is_restricted', is_restricted))
        if is_ultra_restricted is not None:
            _form_params.append(('is_ultra_restricted', is_ultra_restricted))
        if channel_ids is not None:
            _form_params.append(('channel_ids', channel_ids))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.users.assign',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_users_invite(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        email: Annotated[StrictStr, Field(description="The email address of the person to invite.")],
        channel_ids: Annotated[StrictStr, Field(description="A comma-separated list of `channel_id`s for this user to join. At least one channel is required.")],
        custom_message: Annotated[Optional[StrictStr], Field(description="An optional message to send to the user in the invite email.")] = None,
        real_name: Annotated[Optional[StrictStr], Field(description="Full name of the user.")] = None,
        resend: Annotated[Optional[StrictBool], Field(description="Allow this invite to be resent in the future if a user has not signed up yet. (default: false)")] = None,
        is_restricted: Annotated[Optional[StrictBool], Field(description="Is this user a multi-channel guest user? (default: false)")] = None,
        is_ultra_restricted: Annotated[Optional[StrictBool], Field(description="Is this user a single channel guest user? (default: false)")] = None,
        guest_expiration_ts: Annotated[Optional[StrictStr], Field(description="Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_invite

        Invite a user to a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param email: The email address of the person to invite. (required)
        :type email: str
        :param channel_ids: A comma-separated list of `channel_id`s for this user to join. At least one channel is required. (required)
        :type channel_ids: str
        :param custom_message: An optional message to send to the user in the invite email.
        :type custom_message: str
        :param real_name: Full name of the user.
        :type real_name: str
        :param resend: Allow this invite to be resent in the future if a user has not signed up yet. (default: false)
        :type resend: bool
        :param is_restricted: Is this user a multi-channel guest user? (default: false)
        :type is_restricted: bool
        :param is_ultra_restricted: Is this user a single channel guest user? (default: false)
        :type is_ultra_restricted: bool
        :param guest_expiration_ts: Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.
        :type guest_expiration_ts: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_invite_serialize(
            token=token,
            team_id=team_id,
            email=email,
            channel_ids=channel_ids,
            custom_message=custom_message,
            real_name=real_name,
            resend=resend,
            is_restricted=is_restricted,
            is_ultra_restricted=is_ultra_restricted,
            guest_expiration_ts=guest_expiration_ts,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_invite_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        email: Annotated[StrictStr, Field(description="The email address of the person to invite.")],
        channel_ids: Annotated[StrictStr, Field(description="A comma-separated list of `channel_id`s for this user to join. At least one channel is required.")],
        custom_message: Annotated[Optional[StrictStr], Field(description="An optional message to send to the user in the invite email.")] = None,
        real_name: Annotated[Optional[StrictStr], Field(description="Full name of the user.")] = None,
        resend: Annotated[Optional[StrictBool], Field(description="Allow this invite to be resent in the future if a user has not signed up yet. (default: false)")] = None,
        is_restricted: Annotated[Optional[StrictBool], Field(description="Is this user a multi-channel guest user? (default: false)")] = None,
        is_ultra_restricted: Annotated[Optional[StrictBool], Field(description="Is this user a single channel guest user? (default: false)")] = None,
        guest_expiration_ts: Annotated[Optional[StrictStr], Field(description="Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_invite

        Invite a user to a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param email: The email address of the person to invite. (required)
        :type email: str
        :param channel_ids: A comma-separated list of `channel_id`s for this user to join. At least one channel is required. (required)
        :type channel_ids: str
        :param custom_message: An optional message to send to the user in the invite email.
        :type custom_message: str
        :param real_name: Full name of the user.
        :type real_name: str
        :param resend: Allow this invite to be resent in the future if a user has not signed up yet. (default: false)
        :type resend: bool
        :param is_restricted: Is this user a multi-channel guest user? (default: false)
        :type is_restricted: bool
        :param is_ultra_restricted: Is this user a single channel guest user? (default: false)
        :type is_ultra_restricted: bool
        :param guest_expiration_ts: Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.
        :type guest_expiration_ts: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_invite_serialize(
            token=token,
            team_id=team_id,
            email=email,
            channel_ids=channel_ids,
            custom_message=custom_message,
            real_name=real_name,
            resend=resend,
            is_restricted=is_restricted,
            is_ultra_restricted=is_ultra_restricted,
            guest_expiration_ts=guest_expiration_ts,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_invite_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        email: Annotated[StrictStr, Field(description="The email address of the person to invite.")],
        channel_ids: Annotated[StrictStr, Field(description="A comma-separated list of `channel_id`s for this user to join. At least one channel is required.")],
        custom_message: Annotated[Optional[StrictStr], Field(description="An optional message to send to the user in the invite email.")] = None,
        real_name: Annotated[Optional[StrictStr], Field(description="Full name of the user.")] = None,
        resend: Annotated[Optional[StrictBool], Field(description="Allow this invite to be resent in the future if a user has not signed up yet. (default: false)")] = None,
        is_restricted: Annotated[Optional[StrictBool], Field(description="Is this user a multi-channel guest user? (default: false)")] = None,
        is_ultra_restricted: Annotated[Optional[StrictBool], Field(description="Is this user a single channel guest user? (default: false)")] = None,
        guest_expiration_ts: Annotated[Optional[StrictStr], Field(description="Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_invite

        Invite a user to a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param email: The email address of the person to invite. (required)
        :type email: str
        :param channel_ids: A comma-separated list of `channel_id`s for this user to join. At least one channel is required. (required)
        :type channel_ids: str
        :param custom_message: An optional message to send to the user in the invite email.
        :type custom_message: str
        :param real_name: Full name of the user.
        :type real_name: str
        :param resend: Allow this invite to be resent in the future if a user has not signed up yet. (default: false)
        :type resend: bool
        :param is_restricted: Is this user a multi-channel guest user? (default: false)
        :type is_restricted: bool
        :param is_ultra_restricted: Is this user a single channel guest user? (default: false)
        :type is_ultra_restricted: bool
        :param guest_expiration_ts: Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.
        :type guest_expiration_ts: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_invite_serialize(
            token=token,
            team_id=team_id,
            email=email,
            channel_ids=channel_ids,
            custom_message=custom_message,
            real_name=real_name,
            resend=resend,
            is_restricted=is_restricted,
            is_ultra_restricted=is_ultra_restricted,
            guest_expiration_ts=guest_expiration_ts,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_invite_serialize(
        self,
        token,
        team_id,
        email,
        channel_ids,
        custom_message,
        real_name,
        resend,
        is_restricted,
        is_ultra_restricted,
        guest_expiration_ts,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if email is not None:
            _form_params.append(('email', email))
        if channel_ids is not None:
            _form_params.append(('channel_ids', channel_ids))
        if custom_message is not None:
            _form_params.append(('custom_message', custom_message))
        if real_name is not None:
            _form_params.append(('real_name', real_name))
        if resend is not None:
            _form_params.append(('resend', resend))
        if is_restricted is not None:
            _form_params.append(('is_restricted', is_restricted))
        if is_ultra_restricted is not None:
            _form_params.append(('is_ultra_restricted', is_ultra_restricted))
        if guest_expiration_ts is not None:
            _form_params.append(('guest_expiration_ts', guest_expiration_ts))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.users.invite',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_users_list(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:read`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Limit for how many users to be retrieved per page")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_list

        List users on a workspace

        :param token: Authentication token. Requires scope: `admin.users:read` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
        :type cursor: str
        :param limit: Limit for how many users to be retrieved per page
        :type limit: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_list_serialize(
            token=token,
            team_id=team_id,
            cursor=cursor,
            limit=limit,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_list_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:read`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Limit for how many users to be retrieved per page")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_list

        List users on a workspace

        :param token: Authentication token. Requires scope: `admin.users:read` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
        :type cursor: str
        :param limit: Limit for how many users to be retrieved per page
        :type limit: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_list_serialize(
            token=token,
            team_id=team_id,
            cursor=cursor,
            limit=limit,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_list_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:read`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Limit for how many users to be retrieved per page")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_list

        List users on a workspace

        :param token: Authentication token. Requires scope: `admin.users:read` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
        :type cursor: str
        :param limit: Limit for how many users to be retrieved per page
        :type limit: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_list_serialize(
            token=token,
            team_id=team_id,
            cursor=cursor,
            limit=limit,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_list_serialize(
        self,
        token,
        team_id,
        cursor,
        limit,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if team_id is not None:
            
            _query_params.append(('team_id', team_id))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/admin.users.list',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_users_remove(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to remove.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_remove

        Remove a user from a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to remove. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_remove_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_remove_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to remove.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_remove

        Remove a user from a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to remove. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_remove_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_remove_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to remove.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_remove

        Remove a user from a workspace.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to remove. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_remove_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_remove_serialize(
        self,
        token,
        team_id,
        user_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if user_id is not None:
            _form_params.append(('user_id', user_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.users.remove',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_users_set_admin(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to designate as an admin.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_set_admin

        Set an existing guest, regular user, or owner to be an admin user.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to designate as an admin. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_admin_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_set_admin_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to designate as an admin.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_set_admin

        Set an existing guest, regular user, or owner to be an admin user.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to designate as an admin. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_admin_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_set_admin_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to designate as an admin.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_set_admin

        Set an existing guest, regular user, or owner to be an admin user.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to designate as an admin. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_admin_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_set_admin_serialize(
        self,
        token,
        team_id,
        user_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if user_id is not None:
            _form_params.append(('user_id', user_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.users.setAdmin',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_users_set_expiration(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to set an expiration for.")],
        expiration_ts: Annotated[StrictInt, Field(description="Timestamp when guest account should be disabled.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_set_expiration

        Set an expiration for a guest user

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to set an expiration for. (required)
        :type user_id: str
        :param expiration_ts: Timestamp when guest account should be disabled. (required)
        :type expiration_ts: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_expiration_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            expiration_ts=expiration_ts,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_set_expiration_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to set an expiration for.")],
        expiration_ts: Annotated[StrictInt, Field(description="Timestamp when guest account should be disabled.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_set_expiration

        Set an expiration for a guest user

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to set an expiration for. (required)
        :type user_id: str
        :param expiration_ts: Timestamp when guest account should be disabled. (required)
        :type expiration_ts: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_expiration_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            expiration_ts=expiration_ts,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_set_expiration_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to set an expiration for.")],
        expiration_ts: Annotated[StrictInt, Field(description="Timestamp when guest account should be disabled.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_set_expiration

        Set an expiration for a guest user

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to set an expiration for. (required)
        :type user_id: str
        :param expiration_ts: Timestamp when guest account should be disabled. (required)
        :type expiration_ts: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_expiration_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            expiration_ts=expiration_ts,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_set_expiration_serialize(
        self,
        token,
        team_id,
        user_id,
        expiration_ts,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if user_id is not None:
            _form_params.append(('user_id', user_id))
        if expiration_ts is not None:
            _form_params.append(('expiration_ts', expiration_ts))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.users.setExpiration',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_users_set_owner(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="Id of the user to promote to owner.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_set_owner

        Set an existing guest, regular user, or admin user to be a workspace owner.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: Id of the user to promote to owner. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_owner_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_set_owner_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="Id of the user to promote to owner.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_set_owner

        Set an existing guest, regular user, or admin user to be a workspace owner.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: Id of the user to promote to owner. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_owner_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_set_owner_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="Id of the user to promote to owner.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_set_owner

        Set an existing guest, regular user, or admin user to be a workspace owner.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: Id of the user to promote to owner. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_owner_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_set_owner_serialize(
        self,
        token,
        team_id,
        user_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if user_id is not None:
            _form_params.append(('user_id', user_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.users.setOwner',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_users_set_regular(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to designate as a regular user.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_users_set_regular

        Set an existing guest user, admin user, or owner to be a regular user.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to designate as a regular user. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_regular_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_users_set_regular_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to designate as a regular user.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_users_set_regular

        Set an existing guest user, admin user, or owner to be a regular user.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to designate as a regular user. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_regular_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_users_set_regular_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.users:write`")],
        team_id: Annotated[StrictStr, Field(description="The ID (`T1234`) of the workspace.")],
        user_id: Annotated[StrictStr, Field(description="The ID of the user to designate as a regular user.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_users_set_regular

        Set an existing guest user, admin user, or owner to be a regular user.

        :param token: Authentication token. Requires scope: `admin.users:write` (required)
        :type token: str
        :param team_id: The ID (`T1234`) of the workspace. (required)
        :type team_id: str
        :param user_id: The ID of the user to designate as a regular user. (required)
        :type user_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_users_set_regular_serialize(
            token=token,
            team_id=team_id,
            user_id=user_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_users_set_regular_serialize(
        self,
        token,
        team_id,
        user_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if user_id is not None:
            _form_params.append(('user_id', user_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.users.setRegular',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# flake8: noqa

# import apis into api package
from slack_beta_ti.api.admin_api import AdminApi
from slack_beta_ti.api.admin_apps_api import AdminAppsApi
from slack_beta_ti.api.admin_apps_approved_api import AdminAppsApprovedApi
from slack_beta_ti.api.admin_apps_requests_api import AdminAppsRequestsApi
from slack_beta_ti.api.admin_apps_restricted_api import AdminAppsRestrictedApi
from slack_beta_ti.api.admin_conversations_api import AdminConversationsApi
from slack_beta_ti.api.admin_conversations_ekm_api import AdminConversationsEkmApi
from slack_beta_ti.api.admin_conversations_restrict_access_api import AdminConversationsRestrictAccessApi
from slack_beta_ti.api.admin_emoji_api import AdminEmojiApi
from slack_beta_ti.api.admin_invite_requests_api import AdminInviteRequestsApi
from slack_beta_ti.api.admin_invite_requests_approved_api import AdminInviteRequestsApprovedApi
from slack_beta_ti.api.admin_invite_requests_denied_api import AdminInviteRequestsDeniedApi
from slack_beta_ti.api.admin_teams_api import AdminTeamsApi
from slack_beta_ti.api.admin_teams_admins_api import AdminTeamsAdminsApi
from slack_beta_ti.api.admin_teams_owners_api import AdminTeamsOwnersApi
from slack_beta_ti.api.admin_teams_settings_api import AdminTeamsSettingsApi
from slack_beta_ti.api.admin_usergroups_api import AdminUsergroupsApi
from slack_beta_ti.api.admin_users_api import AdminUsersApi
from slack_beta_ti.api.admin_users_session_api import AdminUsersSessionApi
from slack_beta_ti.api.api_api import ApiApi
from slack_beta_ti.api.apps_api import AppsApi
from slack_beta_ti.api.apps_event_authorizations_api import AppsEventAuthorizationsApi
from slack_beta_ti.api.apps_permissions_api import AppsPermissionsApi
from slack_beta_ti.api.apps_permissions_resources_api import AppsPermissionsResourcesApi
from slack_beta_ti.api.apps_permissions_scopes_api import AppsPermissionsScopesApi
from slack_beta_ti.api.apps_permissions_users_api import AppsPermissionsUsersApi
from slack_beta_ti.api.auth_api import AuthApi
from slack_beta_ti.api.bots_api import BotsApi
from slack_beta_ti.api.calls_api import CallsApi
from slack_beta_ti.api.calls_participants_api import CallsParticipantsApi
from slack_beta_ti.api.chat_api import ChatApi
from slack_beta_ti.api.chat_scheduled_messages_api import ChatScheduledMessagesApi
from slack_beta_ti.api.conversations_api import ConversationsApi
from slack_beta_ti.api.dialog_api import DialogApi
from slack_beta_ti.api.dnd_api import DndApi
from slack_beta_ti.api.emoji_api import EmojiApi
from slack_beta_ti.api.files_api import FilesApi
from slack_beta_ti.api.files_comments_api import FilesCommentsApi
from slack_beta_ti.api.files_remote_api import FilesRemoteApi
from slack_beta_ti.api.migration_api import MigrationApi
from slack_beta_ti.api.oauth_api import OauthApi
from slack_beta_ti.api.oauth_v2_api import OauthV2Api
from slack_beta_ti.api.pins_api import PinsApi
from slack_beta_ti.api.reactions_api import ReactionsApi
from slack_beta_ti.api.reminders_api import RemindersApi
from slack_beta_ti.api.rtm_api import RtmApi
from slack_beta_ti.api.search_api import SearchApi
from slack_beta_ti.api.stars_api import StarsApi
from slack_beta_ti.api.team_api import TeamApi
from slack_beta_ti.api.team_profile_api import TeamProfileApi
from slack_beta_ti.api.usergroups_api import UsergroupsApi
from slack_beta_ti.api.usergroups_users_api import UsergroupsUsersApi
from slack_beta_ti.api.users_api import UsersApi
from slack_beta_ti.api.users_profile_api import UsersProfileApi
from slack_beta_ti.api.views_api import ViewsApi
from slack_beta_ti.api.workflows_api import WorkflowsApi




# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from slack_beta_ti.models.default_success_template import DefaultSuccessTemplate

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class WorkflowsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def workflows_step_completed(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_execute_id: Annotated[StrictStr, Field(description="Context identifier that maps to the correct workflow step execution.")],
        outputs: Annotated[Optional[StrictStr], Field(description="Key-value object of outputs from your step. Keys of this object reflect the configured `key` properties of your [`outputs`](/reference/workflows/workflow_step#output) array from your `workflow_step` object.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """workflows_step_completed

        Indicate that an app's step in a workflow completed execution.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_execute_id: Context identifier that maps to the correct workflow step execution. (required)
        :type workflow_step_execute_id: str
        :param outputs: Key-value object of outputs from your step. Keys of this object reflect the configured `key` properties of your [`outputs`](/reference/workflows/workflow_step#output) array from your `workflow_step` object.
        :type outputs: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_step_completed_serialize(
            token=token,
            workflow_step_execute_id=workflow_step_execute_id,
            outputs=outputs,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def workflows_step_completed_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_execute_id: Annotated[StrictStr, Field(description="Context identifier that maps to the correct workflow step execution.")],
        outputs: Annotated[Optional[StrictStr], Field(description="Key-value object of outputs from your step. Keys of this object reflect the configured `key` properties of your [`outputs`](/reference/workflows/workflow_step#output) array from your `workflow_step` object.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """workflows_step_completed

        Indicate that an app's step in a workflow completed execution.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_execute_id: Context identifier that maps to the correct workflow step execution. (required)
        :type workflow_step_execute_id: str
        :param outputs: Key-value object of outputs from your step. Keys of this object reflect the configured `key` properties of your [`outputs`](/reference/workflows/workflow_step#output) array from your `workflow_step` object.
        :type outputs: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_step_completed_serialize(
            token=token,
            workflow_step_execute_id=workflow_step_execute_id,
            outputs=outputs,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def workflows_step_completed_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_execute_id: Annotated[StrictStr, Field(description="Context identifier that maps to the correct workflow step execution.")],
        outputs: Annotated[Optional[StrictStr], Field(description="Key-value object of outputs from your step. Keys of this object reflect the configured `key` properties of your [`outputs`](/reference/workflows/workflow_step#output) array from your `workflow_step` object.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """workflows_step_completed

        Indicate that an app's step in a workflow completed execution.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_execute_id: Context identifier that maps to the correct workflow step execution. (required)
        :type workflow_step_execute_id: str
        :param outputs: Key-value object of outputs from your step. Keys of this object reflect the configured `key` properties of your [`outputs`](/reference/workflows/workflow_step#output) array from your `workflow_step` object.
        :type outputs: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_step_completed_serialize(
            token=token,
            workflow_step_execute_id=workflow_step_execute_id,
            outputs=outputs,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _workflows_step_completed_serialize(
        self,
        token,
        workflow_step_execute_id,
        outputs,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if workflow_step_execute_id is not None:
            
            _query_params.append(('workflow_step_execute_id', workflow_step_execute_id))
            
        if outputs is not None:
            
            _query_params.append(('outputs', outputs))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/workflows.stepCompleted',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def workflows_step_failed(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_execute_id: Annotated[StrictStr, Field(description="Context identifier that maps to the correct workflow step execution.")],
        error: Annotated[StrictStr, Field(description="A JSON-based object with a `message` property that should contain a human readable error message.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """workflows_step_failed

        Indicate that an app's step in a workflow failed to execute.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_execute_id: Context identifier that maps to the correct workflow step execution. (required)
        :type workflow_step_execute_id: str
        :param error: A JSON-based object with a `message` property that should contain a human readable error message. (required)
        :type error: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_step_failed_serialize(
            token=token,
            workflow_step_execute_id=workflow_step_execute_id,
            error=error,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def workflows_step_failed_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_execute_id: Annotated[StrictStr, Field(description="Context identifier that maps to the correct workflow step execution.")],
        error: Annotated[StrictStr, Field(description="A JSON-based object with a `message` property that should contain a human readable error message.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """workflows_step_failed

        Indicate that an app's step in a workflow failed to execute.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_execute_id: Context identifier that maps to the correct workflow step execution. (required)
        :type workflow_step_execute_id: str
        :param error: A JSON-based object with a `message` property that should contain a human readable error message. (required)
        :type error: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_step_failed_serialize(
            token=token,
            workflow_step_execute_id=workflow_step_execute_id,
            error=error,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def workflows_step_failed_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_execute_id: Annotated[StrictStr, Field(description="Context identifier that maps to the correct workflow step execution.")],
        error: Annotated[StrictStr, Field(description="A JSON-based object with a `message` property that should contain a human readable error message.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """workflows_step_failed

        Indicate that an app's step in a workflow failed to execute.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_execute_id: Context identifier that maps to the correct workflow step execution. (required)
        :type workflow_step_execute_id: str
        :param error: A JSON-based object with a `message` property that should contain a human readable error message. (required)
        :type error: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_step_failed_serialize(
            token=token,
            workflow_step_execute_id=workflow_step_execute_id,
            error=error,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _workflows_step_failed_serialize(
        self,
        token,
        workflow_step_execute_id,
        error,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if workflow_step_execute_id is not None:
            
            _query_params.append(('workflow_step_execute_id', workflow_step_execute_id))
            
        if error is not None:
            
            _query_params.append(('error', error))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/workflows.stepFailed',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def workflows_update_step(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_edit_id: Annotated[StrictStr, Field(description="A context identifier provided with `view_submission` payloads used to call back to `workflows.updateStep`.")],
        inputs: Annotated[Optional[StrictStr], Field(description="A JSON key-value map of inputs required from a user during configuration. This is the data your app expects to receive when the workflow step starts. **Please note**: the embedded variable format is set and replaced by the workflow system. You cannot create custom variables that will be replaced at runtime. [Read more about variables in workflow steps here](/workflows/steps#variables).")] = None,
        outputs: Annotated[Optional[StrictStr], Field(description="An JSON array of output objects used during step execution. This is the data your app agrees to provide when your workflow step was executed.")] = None,
        step_name: Annotated[Optional[StrictStr], Field(description="An optional field that can be used to override the step name that is shown in the Workflow Builder.")] = None,
        step_image_url: Annotated[Optional[StrictStr], Field(description="An optional field that can be used to override app image that is shown in the Workflow Builder.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """workflows_update_step

        Update the configuration for a workflow extension step.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_edit_id: A context identifier provided with `view_submission` payloads used to call back to `workflows.updateStep`. (required)
        :type workflow_step_edit_id: str
        :param inputs: A JSON key-value map of inputs required from a user during configuration. This is the data your app expects to receive when the workflow step starts. **Please note**: the embedded variable format is set and replaced by the workflow system. You cannot create custom variables that will be replaced at runtime. [Read more about variables in workflow steps here](/workflows/steps#variables).
        :type inputs: str
        :param outputs: An JSON array of output objects used during step execution. This is the data your app agrees to provide when your workflow step was executed.
        :type outputs: str
        :param step_name: An optional field that can be used to override the step name that is shown in the Workflow Builder.
        :type step_name: str
        :param step_image_url: An optional field that can be used to override app image that is shown in the Workflow Builder.
        :type step_image_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_update_step_serialize(
            token=token,
            workflow_step_edit_id=workflow_step_edit_id,
            inputs=inputs,
            outputs=outputs,
            step_name=step_name,
            step_image_url=step_image_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def workflows_update_step_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_edit_id: Annotated[StrictStr, Field(description="A context identifier provided with `view_submission` payloads used to call back to `workflows.updateStep`.")],
        inputs: Annotated[Optional[StrictStr], Field(description="A JSON key-value map of inputs required from a user during configuration. This is the data your app expects to receive when the workflow step starts. **Please note**: the embedded variable format is set and replaced by the workflow system. You cannot create custom variables that will be replaced at runtime. [Read more about variables in workflow steps here](/workflows/steps#variables).")] = None,
        outputs: Annotated[Optional[StrictStr], Field(description="An JSON array of output objects used during step execution. This is the data your app agrees to provide when your workflow step was executed.")] = None,
        step_name: Annotated[Optional[StrictStr], Field(description="An optional field that can be used to override the step name that is shown in the Workflow Builder.")] = None,
        step_image_url: Annotated[Optional[StrictStr], Field(description="An optional field that can be used to override app image that is shown in the Workflow Builder.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """workflows_update_step

        Update the configuration for a workflow extension step.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_edit_id: A context identifier provided with `view_submission` payloads used to call back to `workflows.updateStep`. (required)
        :type workflow_step_edit_id: str
        :param inputs: A JSON key-value map of inputs required from a user during configuration. This is the data your app expects to receive when the workflow step starts. **Please note**: the embedded variable format is set and replaced by the workflow system. You cannot create custom variables that will be replaced at runtime. [Read more about variables in workflow steps here](/workflows/steps#variables).
        :type inputs: str
        :param outputs: An JSON array of output objects used during step execution. This is the data your app agrees to provide when your workflow step was executed.
        :type outputs: str
        :param step_name: An optional field that can be used to override the step name that is shown in the Workflow Builder.
        :type step_name: str
        :param step_image_url: An optional field that can be used to override app image that is shown in the Workflow Builder.
        :type step_image_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_update_step_serialize(
            token=token,
            workflow_step_edit_id=workflow_step_edit_id,
            inputs=inputs,
            outputs=outputs,
            step_name=step_name,
            step_image_url=step_image_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def workflows_update_step_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `workflow.steps:execute`")],
        workflow_step_edit_id: Annotated[StrictStr, Field(description="A context identifier provided with `view_submission` payloads used to call back to `workflows.updateStep`.")],
        inputs: Annotated[Optional[StrictStr], Field(description="A JSON key-value map of inputs required from a user during configuration. This is the data your app expects to receive when the workflow step starts. **Please note**: the embedded variable format is set and replaced by the workflow system. You cannot create custom variables that will be replaced at runtime. [Read more about variables in workflow steps here](/workflows/steps#variables).")] = None,
        outputs: Annotated[Optional[StrictStr], Field(description="An JSON array of output objects used during step execution. This is the data your app agrees to provide when your workflow step was executed.")] = None,
        step_name: Annotated[Optional[StrictStr], Field(description="An optional field that can be used to override the step name that is shown in the Workflow Builder.")] = None,
        step_image_url: Annotated[Optional[StrictStr], Field(description="An optional field that can be used to override app image that is shown in the Workflow Builder.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """workflows_update_step

        Update the configuration for a workflow extension step.

        :param token: Authentication token. Requires scope: `workflow.steps:execute` (required)
        :type token: str
        :param workflow_step_edit_id: A context identifier provided with `view_submission` payloads used to call back to `workflows.updateStep`. (required)
        :type workflow_step_edit_id: str
        :param inputs: A JSON key-value map of inputs required from a user during configuration. This is the data your app expects to receive when the workflow step starts. **Please note**: the embedded variable format is set and replaced by the workflow system. You cannot create custom variables that will be replaced at runtime. [Read more about variables in workflow steps here](/workflows/steps#variables).
        :type inputs: str
        :param outputs: An JSON array of output objects used during step execution. This is the data your app agrees to provide when your workflow step was executed.
        :type outputs: str
        :param step_name: An optional field that can be used to override the step name that is shown in the Workflow Builder.
        :type step_name: str
        :param step_image_url: An optional field that can be used to override app image that is shown in the Workflow Builder.
        :type step_image_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._workflows_update_step_serialize(
            token=token,
            workflow_step_edit_id=workflow_step_edit_id,
            inputs=inputs,
            outputs=outputs,
            step_name=step_name,
            step_image_url=step_image_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _workflows_update_step_serialize(
        self,
        token,
        workflow_step_edit_id,
        inputs,
        outputs,
        step_name,
        step_image_url,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if workflow_step_edit_id is not None:
            
            _query_params.append(('workflow_step_edit_id', workflow_step_edit_id))
            
        if inputs is not None:
            
            _query_params.append(('inputs', inputs))
            
        if outputs is not None:
            
            _query_params.append(('outputs', outputs))
            
        if step_name is not None:
            
            _query_params.append(('step_name', step_name))
            
        if step_image_url is not None:
            
            _query_params.append(('step_image_url', step_image_url))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/workflows.updateStep',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from slack_beta_ti.models.objs_external_org_migrations import ObjsExternalOrgMigrations
from slack_beta_ti.models.objs_icon import ObjsIcon
from slack_beta_ti.models.objs_primary_owner import ObjsPrimaryOwner
from slack_beta_ti.models.objs_team_sso_provider import ObjsTeamSsoProvider
from typing import Optional, Set
from typing_extensions import Self

class ObjsTeam(BaseModel):
    """
    ObjsTeam
    """ # noqa: E501
    archived: Optional[StrictBool] = None
    avatar_base_url: Optional[StrictStr] = None
    created: Optional[StrictInt] = None
    date_create: Optional[StrictInt] = None
    deleted: Optional[StrictBool] = None
    discoverable: Optional[Dict[str, Any]] = None
    domain: StrictStr
    email_domain: StrictStr
    enterprise_id: Optional[Annotated[str, Field(strict=True)]] = None
    enterprise_name: Optional[StrictStr] = None
    external_org_migrations: Optional[ObjsExternalOrgMigrations] = None
    has_compliance_export: Optional[StrictBool] = None
    icon: ObjsIcon
    id: Annotated[str, Field(strict=True)]
    is_assigned: Optional[StrictBool] = None
    is_enterprise: Optional[StrictInt] = None
    is_over_storage_limit: Optional[StrictBool] = None
    limit_ts: Optional[StrictInt] = None
    locale: Optional[StrictStr] = None
    messages_count: Optional[StrictInt] = None
    msg_edit_window_mins: Optional[StrictInt] = None
    name: StrictStr
    over_integrations_limit: Optional[StrictBool] = None
    over_storage_limit: Optional[StrictBool] = None
    pay_prod_cur: Optional[StrictStr] = None
    plan: Optional[StrictStr] = None
    primary_owner: Optional[ObjsPrimaryOwner] = None
    sso_provider: Optional[ObjsTeamSsoProvider] = None
    __properties: ClassVar[List[str]] = ["archived", "avatar_base_url", "created", "date_create", "deleted", "discoverable", "domain", "email_domain", "enterprise_id", "enterprise_name", "external_org_migrations", "has_compliance_export", "icon", "id", "is_assigned", "is_enterprise", "is_over_storage_limit", "limit_ts", "locale", "messages_count", "msg_edit_window_mins", "name", "over_integrations_limit", "over_storage_limit", "pay_prod_cur", "plan", "primary_owner", "sso_provider"]

    @field_validator('enterprise_id')
    def enterprise_id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[E][A-Z0-9]{8,}$", value):
            raise ValueError(r"must validate the regular expression /^[E][A-Z0-9]{8,}$/")
        return value

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[TE][A-Z0-9]{8,}$", value):
            raise ValueError(r"must validate the regular expression /^[TE][A-Z0-9]{8,}$/")
        return value

    @field_validator('plan')
    def plan_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['', 'std', 'plus', 'compliance', 'enterprise']):
            raise ValueError("must be one of enum values ('', 'std', 'plus', 'compliance', 'enterprise')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ObjsTeam from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of external_org_migrations
        if self.external_org_migrations:
            _dict['external_org_migrations'] = self.external_org_migrations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of icon
        if self.icon:
            _dict['icon'] = self.icon.to_dict()
        # override the default output from pydantic by calling `to_dict()` of primary_owner
        if self.primary_owner:
            _dict['primary_owner'] = self.primary_owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sso_provider
        if self.sso_provider:
            _dict['sso_provider'] = self.sso_provider.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ObjsTeam from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "archived": obj.get("archived"),
            "avatar_base_url": obj.get("avatar_base_url"),
            "created": obj.get("created"),
            "date_create": obj.get("date_create"),
            "deleted": obj.get("deleted"),
            "discoverable": obj.get("discoverable"),
            "domain": obj.get("domain"),
            "email_domain": obj.get("email_domain"),
            "enterprise_id": obj.get("enterprise_id"),
            "enterprise_name": obj.get("enterprise_name"),
            "external_org_migrations": ObjsExternalOrgMigrations.from_dict(obj["external_org_migrations"]) if obj.get("external_org_migrations") is not None else None,
            "has_compliance_export": obj.get("has_compliance_export"),
            "icon": ObjsIcon.from_dict(obj["icon"]) if obj.get("icon") is not None else None,
            "id": obj.get("id"),
            "is_assigned": obj.get("is_assigned"),
            "is_enterprise": obj.get("is_enterprise"),
            "is_over_storage_limit": obj.get("is_over_storage_limit"),
            "limit_ts": obj.get("limit_ts"),
            "locale": obj.get("locale"),
            "messages_count": obj.get("messages_count"),
            "msg_edit_window_mins": obj.get("msg_edit_window_mins"),
            "name": obj.get("name"),
            "over_integrations_limit": obj.get("over_integrations_limit"),
            "over_storage_limit": obj.get("over_storage_limit"),
            "pay_prod_cur": obj.get("pay_prod_cur"),
            "plan": obj.get("plan"),
            "primary_owner": ObjsPrimaryOwner.from_dict(obj["primary_owner"]) if obj.get("primary_owner") is not None else None,
            "sso_provider": ObjsTeamSsoProvider.from_dict(obj["sso_provider"]) if obj.get("sso_provider") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_team import ObjsTeam

class TestObjsTeam(unittest.TestCase):
    """ObjsTeam unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsTeam:
        """Test ObjsTeam
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsTeam`
        """
        model = ObjsTeam()
        if include_optional:
            return ObjsTeam(
                archived = True,
                avatar_base_url = '',
                created = 56,
                date_create = 56,
                deleted = True,
                discoverable = None,
                domain = '',
                email_domain = '',
                enterprise_id = 'EQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                enterprise_name = '',
                external_org_migrations = slack_beta_ti.models.external_org_migrations.External Org Migrations(
                    current = [
                        slack_beta_ti.models.objs_external_org_migrations_current_inner.objs_external_org_migrations_current_inner(
                            date_started = 56, 
                            team_id = '', )
                        ], 
                    date_updated = 56, ),
                has_compliance_export = True,
                icon = slack_beta_ti.models.objs_icon.objs_icon(
                    image_102 = '', 
                    image_132 = '', 
                    image_230 = '', 
                    image_34 = '', 
                    image_44 = '', 
                    image_68 = '', 
                    image_88 = '', 
                    image_default = True, ),
                id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                is_assigned = True,
                is_enterprise = 56,
                is_over_storage_limit = True,
                limit_ts = 56,
                locale = '',
                messages_count = 56,
                msg_edit_window_mins = 56,
                name = '',
                over_integrations_limit = True,
                over_storage_limit = True,
                pay_prod_cur = '',
                plan = '',
                primary_owner = slack_beta_ti.models.objs_primary_owner.objs_primary_owner(
                    email = '', 
                    id = '', ),
                sso_provider = slack_beta_ti.models.objs_team_sso_provider.objs_team_sso_provider(
                    label = '', 
                    name = '', 
                    type = '', )
            )
        else:
            return ObjsTeam(
                domain = '',
                email_domain = '',
                icon = slack_beta_ti.models.objs_icon.objs_icon(
                    image_102 = '', 
                    image_132 = '', 
                    image_230 = '', 
                    image_34 = '', 
                    image_44 = '', 
                    image_68 = '', 
                    image_88 = '', 
                    image_default = True, ),
                id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                name = '',
        )
        """

    def testObjsTeam(self):
        """Test ObjsTeam"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from slack_beta_ti.models.objs_bot_profile import ObjsBotProfile
from slack_beta_ti.models.objs_comment import ObjsComment
from slack_beta_ti.models.objs_file import ObjsFile
from slack_beta_ti.models.objs_reaction import ObjsReaction
from slack_beta_ti.models.objs_user_profile_short import ObjsUserProfileShort
from typing import Optional, Set
from typing_extensions import Self

class ObjsMessage(BaseModel):
    """
    ObjsMessage
    """ # noqa: E501
    attachments: Optional[Annotated[List[Dict[str, Any]], Field(min_length=1)]] = None
    blocks: Optional[List[Dict[str, Any]]] = Field(default=None, description="This is a very loose definition, in the future, we'll populate this with deeper schema in this definition namespace.")
    bot_id: Optional[Dict[str, Any]] = None
    bot_profile: Optional[ObjsBotProfile] = None
    client_msg_id: Optional[StrictStr] = None
    comment: Optional[ObjsComment] = None
    display_as_bot: Optional[StrictBool] = None
    file: Optional[ObjsFile] = None
    files: Optional[Annotated[List[ObjsFile], Field(min_length=1)]] = None
    icons: Optional[Dict[str, Any]] = None
    inviter: Optional[Annotated[str, Field(strict=True)]] = None
    is_delayed_message: Optional[StrictBool] = None
    is_intro: Optional[StrictBool] = None
    is_starred: Optional[StrictBool] = None
    last_read: Optional[Annotated[str, Field(strict=True)]] = None
    latest_reply: Optional[Annotated[str, Field(strict=True)]] = None
    name: Optional[StrictStr] = None
    old_name: Optional[StrictStr] = None
    parent_user_id: Optional[Annotated[str, Field(strict=True)]] = None
    permalink: Optional[StrictStr] = None
    pinned_to: Optional[List[Annotated[str, Field(strict=True)]]] = None
    purpose: Optional[StrictStr] = None
    reactions: Optional[List[ObjsReaction]] = None
    reply_count: Optional[StrictInt] = None
    reply_users: Optional[Annotated[List[Annotated[str, Field(strict=True)]], Field(min_length=1)]] = None
    reply_users_count: Optional[StrictInt] = None
    source_team: Optional[Annotated[str, Field(strict=True)]] = None
    subscribed: Optional[StrictBool] = None
    subtype: Optional[StrictStr] = None
    team: Optional[Annotated[str, Field(strict=True)]] = None
    text: StrictStr
    thread_ts: Optional[Annotated[str, Field(strict=True)]] = None
    topic: Optional[StrictStr] = None
    ts: Annotated[str, Field(strict=True)]
    type: StrictStr
    unread_count: Optional[StrictInt] = None
    upload: Optional[StrictBool] = None
    user: Optional[Annotated[str, Field(strict=True)]] = None
    user_profile: Optional[ObjsUserProfileShort] = None
    user_team: Optional[Annotated[str, Field(strict=True)]] = None
    username: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["attachments", "blocks", "bot_id", "bot_profile", "client_msg_id", "comment", "display_as_bot", "file", "files", "icons", "inviter", "is_delayed_message", "is_intro", "is_starred", "last_read", "latest_reply", "name", "old_name", "parent_user_id", "permalink", "pinned_to", "purpose", "reactions", "reply_count", "reply_users", "reply_users_count", "source_team", "subscribed", "subtype", "team", "text", "thread_ts", "topic", "ts", "type", "unread_count", "upload", "user", "user_profile", "user_team", "username"]

    @field_validator('inviter')
    def inviter_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('last_read')
    def last_read_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^\d{10}\.\d{6}$", value):
            raise ValueError(r"must validate the regular expression /^\d{10}\.\d{6}$/")
        return value

    @field_validator('latest_reply')
    def latest_reply_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^\d{10}\.\d{6}$", value):
            raise ValueError(r"must validate the regular expression /^\d{10}\.\d{6}$/")
        return value

    @field_validator('parent_user_id')
    def parent_user_id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('source_team')
    def source_team_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[TE][A-Z0-9]{8,}$", value):
            raise ValueError(r"must validate the regular expression /^[TE][A-Z0-9]{8,}$/")
        return value

    @field_validator('team')
    def team_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[TE][A-Z0-9]{8,}$", value):
            raise ValueError(r"must validate the regular expression /^[TE][A-Z0-9]{8,}$/")
        return value

    @field_validator('thread_ts')
    def thread_ts_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^\d{10}\.\d{6}$", value):
            raise ValueError(r"must validate the regular expression /^\d{10}\.\d{6}$/")
        return value

    @field_validator('ts')
    def ts_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^\d{10}\.\d{6}$", value):
            raise ValueError(r"must validate the regular expression /^\d{10}\.\d{6}$/")
        return value

    @field_validator('user')
    def user_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('user_team')
    def user_team_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[TE][A-Z0-9]{8,}$", value):
            raise ValueError(r"must validate the regular expression /^[TE][A-Z0-9]{8,}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ObjsMessage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of bot_profile
        if self.bot_profile:
            _dict['bot_profile'] = self.bot_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of comment
        if self.comment:
            _dict['comment'] = self.comment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of file
        if self.file:
            _dict['file'] = self.file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in files (list)
        _items = []
        if self.files:
            for _item_files in self.files:
                if _item_files:
                    _items.append(_item_files.to_dict())
            _dict['files'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in reactions (list)
        _items = []
        if self.reactions:
            for _item_reactions in self.reactions:
                if _item_reactions:
                    _items.append(_item_reactions.to_dict())
            _dict['reactions'] = _items
        # override the default output from pydantic by calling `to_dict()` of user_profile
        if self.user_profile:
            _dict['user_profile'] = self.user_profile.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ObjsMessage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "attachments": obj.get("attachments"),
            "blocks": obj.get("blocks"),
            "bot_id": obj.get("bot_id"),
            "bot_profile": ObjsBotProfile.from_dict(obj["bot_profile"]) if obj.get("bot_profile") is not None else None,
            "client_msg_id": obj.get("client_msg_id"),
            "comment": ObjsComment.from_dict(obj["comment"]) if obj.get("comment") is not None else None,
            "display_as_bot": obj.get("display_as_bot"),
            "file": ObjsFile.from_dict(obj["file"]) if obj.get("file") is not None else None,
            "files": [ObjsFile.from_dict(_item) for _item in obj["files"]] if obj.get("files") is not None else None,
            "icons": obj.get("icons"),
            "inviter": obj.get("inviter"),
            "is_delayed_message": obj.get("is_delayed_message"),
            "is_intro": obj.get("is_intro"),
            "is_starred": obj.get("is_starred"),
            "last_read": obj.get("last_read"),
            "latest_reply": obj.get("latest_reply"),
            "name": obj.get("name"),
            "old_name": obj.get("old_name"),
            "parent_user_id": obj.get("parent_user_id"),
            "permalink": obj.get("permalink"),
            "pinned_to": obj.get("pinned_to"),
            "purpose": obj.get("purpose"),
            "reactions": [ObjsReaction.from_dict(_item) for _item in obj["reactions"]] if obj.get("reactions") is not None else None,
            "reply_count": obj.get("reply_count"),
            "reply_users": obj.get("reply_users"),
            "reply_users_count": obj.get("reply_users_count"),
            "source_team": obj.get("source_team"),
            "subscribed": obj.get("subscribed"),
            "subtype": obj.get("subtype"),
            "team": obj.get("team"),
            "text": obj.get("text"),
            "thread_ts": obj.get("thread_ts"),
            "topic": obj.get("topic"),
            "ts": obj.get("ts"),
            "type": obj.get("type"),
            "unread_count": obj.get("unread_count"),
            "upload": obj.get("upload"),
            "user": obj.get("user"),
            "user_profile": ObjsUserProfileShort.from_dict(obj["user_profile"]) if obj.get("user_profile") is not None else None,
            "user_team": obj.get("user_team"),
            "username": obj.get("username")
        })
        return _obj





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from slack_beta_ti.models.default_success_template import DefaultSuccessTemplate

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class SearchApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def search_messages(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `search:read`")],
        query: Annotated[StrictStr, Field(description="Search query.")],
        count: Annotated[Optional[StrictInt], Field(description="Pass the number of results you want per \"page\". Maximum of `100`.")] = None,
        highlight: Annotated[Optional[StrictBool], Field(description="Pass a value of `true` to enable query highlight markers (see below).")] = None,
        page: Optional[StrictInt] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Return matches sorted by either `score` or `timestamp`.")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="Change sort direction to ascending (`asc`) or descending (`desc`).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """search_messages

        Searches for messages matching a query.

        :param token: Authentication token. Requires scope: `search:read` (required)
        :type token: str
        :param query: Search query. (required)
        :type query: str
        :param count: Pass the number of results you want per \"page\". Maximum of `100`.
        :type count: int
        :param highlight: Pass a value of `true` to enable query highlight markers (see below).
        :type highlight: bool
        :param page:
        :type page: int
        :param sort: Return matches sorted by either `score` or `timestamp`.
        :type sort: str
        :param sort_dir: Change sort direction to ascending (`asc`) or descending (`desc`).
        :type sort_dir: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_messages_serialize(
            token=token,
            query=query,
            count=count,
            highlight=highlight,
            page=page,
            sort=sort,
            sort_dir=sort_dir,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_messages_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `search:read`")],
        query: Annotated[StrictStr, Field(description="Search query.")],
        count: Annotated[Optional[StrictInt], Field(description="Pass the number of results you want per \"page\". Maximum of `100`.")] = None,
        highlight: Annotated[Optional[StrictBool], Field(description="Pass a value of `true` to enable query highlight markers (see below).")] = None,
        page: Optional[StrictInt] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Return matches sorted by either `score` or `timestamp`.")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="Change sort direction to ascending (`asc`) or descending (`desc`).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """search_messages

        Searches for messages matching a query.

        :param token: Authentication token. Requires scope: `search:read` (required)
        :type token: str
        :param query: Search query. (required)
        :type query: str
        :param count: Pass the number of results you want per \"page\". Maximum of `100`.
        :type count: int
        :param highlight: Pass a value of `true` to enable query highlight markers (see below).
        :type highlight: bool
        :param page:
        :type page: int
        :param sort: Return matches sorted by either `score` or `timestamp`.
        :type sort: str
        :param sort_dir: Change sort direction to ascending (`asc`) or descending (`desc`).
        :type sort_dir: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_messages_serialize(
            token=token,
            query=query,
            count=count,
            highlight=highlight,
            page=page,
            sort=sort,
            sort_dir=sort_dir,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_messages_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `search:read`")],
        query: Annotated[StrictStr, Field(description="Search query.")],
        count: Annotated[Optional[StrictInt], Field(description="Pass the number of results you want per \"page\". Maximum of `100`.")] = None,
        highlight: Annotated[Optional[StrictBool], Field(description="Pass a value of `true` to enable query highlight markers (see below).")] = None,
        page: Optional[StrictInt] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Return matches sorted by either `score` or `timestamp`.")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="Change sort direction to ascending (`asc`) or descending (`desc`).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """search_messages

        Searches for messages matching a query.

        :param token: Authentication token. Requires scope: `search:read` (required)
        :type token: str
        :param query: Search query. (required)
        :type query: str
        :param count: Pass the number of results you want per \"page\". Maximum of `100`.
        :type count: int
        :param highlight: Pass a value of `true` to enable query highlight markers (see below).
        :type highlight: bool
        :param page:
        :type page: int
        :param sort: Return matches sorted by either `score` or `timestamp`.
        :type sort: str
        :param sort_dir: Change sort direction to ascending (`asc`) or descending (`desc`).
        :type sort_dir: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_messages_serialize(
            token=token,
            query=query,
            count=count,
            highlight=highlight,
            page=page,
            sort=sort,
            sort_dir=sort_dir,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _search_messages_serialize(
        self,
        token,
        query,
        count,
        highlight,
        page,
        sort,
        sort_dir,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if count is not None:
            
            _query_params.append(('count', count))
            
        if highlight is not None:
            
            _query_params.append(('highlight', highlight))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if query is not None:
            
            _query_params.append(('query', query))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if sort_dir is not None:
            
            _query_params.append(('sort_dir', sort_dir))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/search.messages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.users_profile_get_schema import UsersProfileGetSchema

class TestUsersProfileGetSchema(unittest.TestCase):
    """UsersProfileGetSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsersProfileGetSchema:
        """Test UsersProfileGetSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsersProfileGetSchema`
        """
        model = UsersProfileGetSchema()
        if include_optional:
            return UsersProfileGetSchema(
                ok = True,
                profile = slack_beta_ti.models.user_profile_object.User profile object(
                    always_active = True, 
                    api_app_id = 'AQ6ZGC', 
                    avatar_hash = '', 
                    bot_id = 'B8Q6ZGCKEC0L3O4GI7XH', 
                    display_name = '', 
                    display_name_normalized = '', 
                    is_app_user = True, 
                    is_custom_image = True, 
                    last_avatar_image_hash = '', 
                    memberships_count = 56, 
                    phone = '', 
                    pronouns = '', 
                    real_name = '', 
                    real_name_normalized = '', 
                    skype = '', 
                    status_default_emoji = '', 
                    status_default_text = '', 
                    status_emoji = '', 
                    status_expiration = 56, 
                    status_text = '', 
                    team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    title = '', 
                    updated = 56, 
                    user_id = '', )
            )
        else:
            return UsersProfileGetSchema(
                ok = True,
                profile = slack_beta_ti.models.user_profile_object.User profile object(
                    always_active = True, 
                    api_app_id = 'AQ6ZGC', 
                    avatar_hash = '', 
                    bot_id = 'B8Q6ZGCKEC0L3O4GI7XH', 
                    display_name = '', 
                    display_name_normalized = '', 
                    is_app_user = True, 
                    is_custom_image = True, 
                    last_avatar_image_hash = '', 
                    memberships_count = 56, 
                    phone = '', 
                    pronouns = '', 
                    real_name = '', 
                    real_name_normalized = '', 
                    skype = '', 
                    status_default_emoji = '', 
                    status_default_text = '', 
                    status_emoji = '', 
                    status_expiration = 56, 
                    status_text = '', 
                    team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    title = '', 
                    updated = 56, 
                    user_id = '', ),
        )
        """

    def testUsersProfileGetSchema(self):
        """Test UsersProfileGetSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.conversations_api import ConversationsApi


class TestConversationsApi(unittest.TestCase):
    """ConversationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConversationsApi()

    def tearDown(self) -> None:
        pass

    def test_conversations_archive(self) -> None:
        """Test case for conversations_archive

        """
        pass

    def test_conversations_close(self) -> None:
        """Test case for conversations_close

        """
        pass

    def test_conversations_create(self) -> None:
        """Test case for conversations_create

        """
        pass

    def test_conversations_history(self) -> None:
        """Test case for conversations_history

        """
        pass

    def test_conversations_info(self) -> None:
        """Test case for conversations_info

        """
        pass

    def test_conversations_invite(self) -> None:
        """Test case for conversations_invite

        """
        pass

    def test_conversations_join(self) -> None:
        """Test case for conversations_join

        """
        pass

    def test_conversations_kick(self) -> None:
        """Test case for conversations_kick

        """
        pass

    def test_conversations_leave(self) -> None:
        """Test case for conversations_leave

        """
        pass

    def test_conversations_list(self) -> None:
        """Test case for conversations_list

        """
        pass

    def test_conversations_mark(self) -> None:
        """Test case for conversations_mark

        """
        pass

    def test_conversations_members(self) -> None:
        """Test case for conversations_members

        """
        pass

    def test_conversations_open(self) -> None:
        """Test case for conversations_open

        """
        pass

    def test_conversations_rename(self) -> None:
        """Test case for conversations_rename

        """
        pass

    def test_conversations_replies(self) -> None:
        """Test case for conversations_replies

        """
        pass

    def test_conversations_set_purpose(self) -> None:
        """Test case for conversations_set_purpose

        """
        pass

    def test_conversations_set_topic(self) -> None:
        """Test case for conversations_set_topic

        """
        pass

    def test_conversations_unarchive(self) -> None:
        """Test case for conversations_unarchive

        """
        pass


if __name__ == '__main__':
    unittest.main()
